@@ -1,6 +1,7 @@
 package terminal
 
 import (
+	"encoding/gob"
 	"fmt"
 	"slices"
 
@@ -8,6 +9,10 @@ import (
 	"github.com/jandedobbeleer/oh-my-posh/src/text"
 )
 
+func init() {
+	gob.Register(&ITermFeatures{})
+}
+
 type iTermFeature string
 
 const (
